[FFmpeg-soc] [soc]: r5199 - in concat: ffmpeg.c.diff libavformat/concat.c libavformat/concatgen.c libavformat/m3u.c libavformat/playlist.c libavformat/playlist.h libavformat/pls.c libavformat/utils.c.diff libav...

gkovacs subversion at mplayerhq.hu
Thu Aug 20 16:35:45 CEST 2009


Author: gkovacs
Date: Thu Aug 20 16:35:45 2009
New Revision: 5199

Log:
rename PlaylistContext to AVPlaylistContext

Modified:
   concat/ffmpeg.c.diff
   concat/libavformat/concat.c
   concat/libavformat/concatgen.c
   concat/libavformat/m3u.c
   concat/libavformat/playlist.c
   concat/libavformat/playlist.h
   concat/libavformat/pls.c
   concat/libavformat/utils.c.diff
   concat/libavformat/xspf.c

Modified: concat/ffmpeg.c.diff
==============================================================================
--- concat/ffmpeg.c.diff	Thu Aug 20 16:28:14 2009	(r5198)
+++ concat/ffmpeg.c.diff	Thu Aug 20 16:35:45 2009	(r5199)
@@ -1,5 +1,5 @@
 diff --git a/ffmpeg.c b/ffmpeg.c
-index 2686e1d..cf47611 100644
+index 2686e1d..f0bf445 100644
 --- a/ffmpeg.c
 +++ b/ffmpeg.c
 @@ -40,6 +40,7 @@
@@ -26,7 +26,7 @@ index 2686e1d..cf47611 100644
      int got_subtitle;
 +    int stream_offset = 0;
      AVPacket avpkt;
-+    PlaylistContext *pl_ctx = ff_playlist_get_context(ic);
++    AVPlaylistContext *pl_ctx = ff_playlist_get_context(ic);
  
 +    if (pl_ctx && pkt) {
 +        ist->st = ic->streams[pkt->stream_index];
@@ -49,7 +49,7 @@ index 2686e1d..cf47611 100644
          AVPacket pkt;
          double ipts_min;
          double opts_min;
-+        PlaylistContext *pl_ctx;
++        AVPlaylistContext *pl_ctx;
 +        int stream_offset;
  
      redo:

Modified: concat/libavformat/concat.c
==============================================================================
--- concat/libavformat/concatgen.c	Thu Aug 20 16:28:14 2009	(r5198)
+++ concat/libavformat/concatgen.c	Thu Aug 20 16:35:45 2009	(r5199)
@@ -35,7 +35,7 @@ int ff_concatgen_read_packet(AVFormatCon
                              AVPacket *pkt)
 {
     int ret, i, stream_index;
-    PlaylistContext *ctx;
+    AVPlaylistContext *ctx;
     AVFormatContext *ic;
     char have_switched_streams = 0;
     ctx = s->priv_data;
@@ -99,7 +99,7 @@ int ff_concatgen_read_seek(AVFormatConte
 {
     int i;
     int64_t localpts_avtimebase, localpts, pts_avtimebase;
-    PlaylistContext *ctx;
+    AVPlaylistContext *ctx;
     AVFormatContext *ic;
     ctx = s->priv_data;
     ic = ctx->icl[ctx->pe_curidx];
@@ -127,7 +127,7 @@ int64_t ff_concatgen_read_timestamp(AVFo
                                     int64_t *pos,
                                     int64_t pos_limit)
 {
-    PlaylistContext *ctx;
+    AVPlaylistContext *ctx;
     AVFormatContext *ic;
     ctx = s->priv_data;
     ic = ctx->icl[ctx->pe_curidx];
@@ -138,7 +138,7 @@ int64_t ff_concatgen_read_timestamp(AVFo
 
 int ff_concatgen_read_close(AVFormatContext *s)
 {
-    PlaylistContext *ctx;
+    AVPlaylistContext *ctx;
     AVFormatContext *ic;
     ctx = s->priv_data;
     ic = ctx->icl[ctx->pe_curidx];
@@ -149,7 +149,7 @@ int ff_concatgen_read_close(AVFormatCont
 
 int ff_concatgen_read_play(AVFormatContext *s)
 {
-    PlaylistContext *ctx;
+    AVPlaylistContext *ctx;
     AVFormatContext *ic;
     ctx = s->priv_data;
     ic = ctx->icl[ctx->pe_curidx];
@@ -158,7 +158,7 @@ int ff_concatgen_read_play(AVFormatConte
 
 int ff_concatgen_read_pause(AVFormatContext *s)
 {
-    PlaylistContext *ctx;
+    AVPlaylistContext *ctx;
     AVFormatContext *ic;
     ctx = s->priv_data;
     ic = ctx->icl[ctx->pe_curidx];

Modified: concat/libavformat/m3u.c
==============================================================================
--- concat/libavformat/m3u.c	Thu Aug 20 16:28:14 2009	(r5198)
+++ concat/libavformat/m3u.c	Thu Aug 20 16:35:45 2009	(r5199)
@@ -43,7 +43,7 @@ static int m3u_probe(AVProbeData *p)
         return 0;
 }
 
-static int m3u_list_files(ByteIOContext *s, PlaylistContext *ctx, const char *filename)
+static int m3u_list_files(ByteIOContext *s, AVPlaylistContext *ctx, const char *filename)
 {
     char **flist;
     int i, k, bufsize;
@@ -77,7 +77,7 @@ static int m3u_list_files(ByteIOContext 
 static int m3u_read_header(AVFormatContext *s,
                            AVFormatParameters *ap)
 {
-    PlaylistContext *ctx = av_mallocz(sizeof(*ctx));
+    AVPlaylistContext *ctx = av_mallocz(sizeof(*ctx));
     m3u_list_files(s->pb, ctx, s->filename);
     s->priv_data = ctx;
     ff_playlist_populate_context(ctx, ctx->pe_curidx);
@@ -88,7 +88,7 @@ static int m3u_read_header(AVFormatConte
 AVInputFormat m3u_demuxer = {
     "m3u",
     NULL_IF_CONFIG_SMALL("CONCAT M3U format"),
-    sizeof(PlaylistContext),
+    sizeof(AVPlaylistContext),
     m3u_probe,
     m3u_read_header,
     ff_concatgen_read_packet,

Modified: concat/libavformat/playlist.c
==============================================================================
--- concat/libavformat/pls.c	Thu Aug 20 16:28:14 2009	(r5198)
+++ concat/libavformat/pls.c	Thu Aug 20 16:35:45 2009	(r5199)
@@ -43,7 +43,7 @@ static int pls_probe(AVProbeData *p)
         return 0;
 }
 
-static int pls_list_files(ByteIOContext *b, PlaylistContext *ctx, const char *filename)
+static int pls_list_files(ByteIOContext *b, AVPlaylistContext *ctx, const char *filename)
 {
     int i, j, k, c;
     unsigned int buflen;
@@ -98,7 +98,7 @@ static int pls_list_files(ByteIOContext 
 static int pls_read_header(AVFormatContext *s,
                            AVFormatParameters *ap)
 {
-    PlaylistContext *ctx = av_mallocz(sizeof(*ctx));
+    AVPlaylistContext *ctx = av_mallocz(sizeof(*ctx));
     if (pls_list_files(s->pb, ctx, s->filename)) {
         fprintf(stderr, "no playlist items found in %s\n", s->filename);
         return AVERROR_EOF;
@@ -112,7 +112,7 @@ static int pls_read_header(AVFormatConte
 AVInputFormat pls_demuxer = {
     "pls",
     NULL_IF_CONFIG_SMALL("CONCAT PLS format"),
-    sizeof(PlaylistContext),
+    sizeof(AVPlaylistContext),
     pls_probe,
     pls_read_header,
     ff_concatgen_read_packet,

Modified: concat/libavformat/utils.c.diff
==============================================================================
--- concat/libavformat/utils.c.diff	Thu Aug 20 16:28:14 2009	(r5198)
+++ concat/libavformat/utils.c.diff	Thu Aug 20 16:35:45 2009	(r5199)
@@ -1,5 +1,5 @@
 diff --git a/libavformat/utils.c b/libavformat/utils.c
-index b9f6c00..fc72e22 100644
+index b9f6c00..31a6268 100644
 --- a/libavformat/utils.c
 +++ b/libavformat/utils.c
 @@ -27,6 +27,7 @@
@@ -28,7 +28,7 @@ index b9f6c00..fc72e22 100644
 +    if (flist && flist_len > 1) {
 +        AVFormatContext *ic = ff_playlist_formatcontext_from_filelist(flist, flist_len);
 +        if (ic) {
-+            PlaylistContext *playlist_ctx = ff_playlist_get_context(ic);
++            AVPlaylistContext *playlist_ctx = ff_playlist_get_context(ic);
 +            if (playlist_ctx) {
 +                av_log(ic, AV_LOG_DEBUG, "Generating playlist from %s\n", filename);
 +                av_strlcpy(ic->filename, filename, sizeof(ic->filename));

Modified: concat/libavformat/xspf.c
==============================================================================
--- concat/libavformat/xspf.c	Thu Aug 20 16:28:14 2009	(r5198)
+++ concat/libavformat/xspf.c	Thu Aug 20 16:35:45 2009	(r5199)
@@ -71,7 +71,7 @@ static int xspf_probe(AVProbeData *p)
         return 0;
 }
 
-static int xspf_list_files(ByteIOContext *b, PlaylistContext *ctx, const char *filename)
+static int xspf_list_files(ByteIOContext *b, AVPlaylistContext *ctx, const char *filename)
 {
     int i, j, k, c;
     unsigned int buflen;
@@ -121,7 +121,7 @@ static int xspf_list_files(ByteIOContext
 static int xspf_read_header(AVFormatContext *s,
                             AVFormatParameters *ap)
 {
-    PlaylistContext *ctx = av_mallocz(sizeof(*ctx));
+    AVPlaylistContext *ctx = av_mallocz(sizeof(*ctx));
     if (xspf_list_files(s->pb, ctx, s->filename)) {
         fprintf(stderr, "no playlist items found in %s\n", s->filename);
         return AVERROR_EOF;
@@ -135,7 +135,7 @@ static int xspf_read_header(AVFormatCont
 AVInputFormat xspf_demuxer = {
     "xspf",
     NULL_IF_CONFIG_SMALL("CONCAT XSPF format"),
-    sizeof(PlaylistContext),
+    sizeof(AVPlaylistContext),
     xspf_probe,
     xspf_read_header,
     ff_concatgen_read_packet,


More information about the FFmpeg-soc mailing list
--- concat/libavformat/concat.c	Thu Aug 20 16:28:14 2009	(r5198)
+++ concat/libavformat/concat.c	Thu Aug 20 16:35:45 2009	(r5199)
@@ -26,8 +26,8 @@
  *
  *  @details This is a minimal concat-type demuxer that can be constructed
  *  by allocating a PlayElem for each playlist item and setting its filename,
  *  then allocating a PlaylistContext, creating a list of PlayElem, and setting
  *  the PlaylistContext in the AVFormatContext.
  */
 
 #include "concat.h"
@@ -46,7 +46,7 @@ static int concat_probe(AVProbeData *p)
     return 0;
 }
 
 // PlaylistContext should be constructed externally
 static int concat_read_header(AVFormatContext *s,
                               AVFormatParameters *ap)
 {
@@ -58,7 +58,7 @@ AVInputFormat* ff_concat_alloc_demuxer(v
     AVInputFormat *cdm  = av_malloc(sizeof(*cdm));
     cdm->name           = "concat";
     cdm->long_name      = NULL_IF_CONFIG_SMALL("CONCAT format");
-    cdm->priv_data_size = sizeof(PlaylistContext);
+    cdm->priv_data_size = sizeof(AVPlaylistContext);
     cdm->read_probe     = concat_probe;
     cdm->read_header    = concat_read_header;
     cdm->read_packet    = ff_concatgen_read_packet;
@@ -26,8 +26,8 @@
  *  @details This is a minimal concat-type demuxer that can be constructed
  *  by allocating a PlayElem for each playlist item and setting its filename,
- *  then allocating a PlaylistContext, creating a list of PlayElem, and setting
- *  the PlaylistContext in the AVFormatContext.
+ *  then allocating a AVPlaylistContext, creating a list of PlayElem, and setting
+ *  the AVPlaylistContext in the AVFormatContext.
  */
 
@@ -46,7 +46,7 @@ static int concat_probe(AVProbeData *p)
 }
 
-// PlaylistContext should be constructed externally
+// AVPlaylistContext should be constructed externally
 static int concat_read_header(AVFormatContext *s,
                               AVFormatParameters *ap)

Modified: concat/libavformat/concatgen.c
==============================================================================
--- concat/libavformat/playlist.c	Thu Aug 20 16:28:14 2009	(r5198)
+++ concat/libavformat/playlist.c	Thu Aug 20 16:35:45 2009	(r5199)
@@ -25,7 +25,7 @@
  *  @brief General components used by playlist formats
  *
  *  @details These functions are used to initialize and manipulate playlists
  *  (PlaylistContext) and their individual playlist elements (PlayElem), each
  *  of which encapsulates its own AVFormatContext. This abstraction is used for
  *  implementing file concatenation and support for playlist formats.
  */
@@ -49,7 +49,7 @@ AVFormatContext *ff_playlist_alloc_forma
     return ic;
 }
 
-void ff_playlist_populate_context(PlaylistContext *ctx, int pe_curidx)
+void ff_playlist_populate_context(AVPlaylistContext *ctx, int pe_curidx)
 {
     ctx->icl = av_realloc(ctx->icl, sizeof(*(ctx->icl)) * (pe_curidx+2));
     ctx->icl[pe_curidx+1] = NULL;
@@ -62,7 +62,7 @@ void ff_playlist_set_streams(AVFormatCon
     int i;
     int offset;
     AVFormatContext *ic;
-    PlaylistContext *ctx = s->priv_data;
+    AVPlaylistContext *ctx = s->priv_data;
     ic = ctx->icl[ctx->pe_curidx];
     offset = ff_playlist_streams_offset_from_playidx(ctx, ctx->pe_curidx);
     ic->iformat->read_header(ic, NULL);
@@ -88,7 +88,7 @@ void ff_playlist_set_streams(AVFormatCon
     s->packet_buffer_end = ic->packet_buffer_end;
 }
 
-PlaylistContext *ff_playlist_get_context(AVFormatContext *ic)
+AVPlaylistContext *ff_playlist_get_context(AVFormatContext *ic)
 {
     if (ic && ic->iformat && ic->iformat->long_name && ic->priv_data &&
         !strncmp(ic->iformat->long_name, "CONCAT", 6))
@@ -99,11 +99,11 @@ PlaylistContext *ff_playlist_get_context
 
 AVFormatContext *ff_playlist_formatcontext_from_filelist(const char **flist, int len)
 {
-    PlaylistContext *ctx;
+    AVPlaylistContext *ctx;
     AVFormatContext *ic;
     ctx = ff_playlist_from_filelist(flist, len);
     if (!ctx) {
-        av_log(NULL, AV_LOG_ERROR, "failed to create PlaylistContext in ff_playlist_formatcontext_from_filelist\n");
+        av_log(NULL, AV_LOG_ERROR, "failed to create AVPlaylistContext in ff_playlist_formatcontext_from_filelist\n");
         return NULL;
     }
     ic = avformat_alloc_context();
@@ -150,10 +150,10 @@ void ff_playlist_split_encodedstring(con
     av_free(sepidx);
 }
 
-PlaylistContext *ff_playlist_from_filelist(const char **flist, int len)
+AVPlaylistContext *ff_playlist_from_filelist(const char **flist, int len)
 {
     int i;
-    PlaylistContext *ctx;
+    AVPlaylistContext *ctx;
     ctx = av_mallocz(sizeof(*ctx));
     if (!ctx) {
         av_log(NULL, AV_LOG_ERROR, "av_mallocz error in ff_playlist_from_encodedstring\n");
@@ -164,9 +164,9 @@ PlaylistContext *ff_playlist_from_fileli
     return ctx;
 }
 
-PlaylistContext *ff_playlist_from_encodedstring(const char *s, const char sep)
+AVPlaylistContext *ff_playlist_from_encodedstring(const char *s, const char sep)
 {
-    PlaylistContext *ctx;
+    AVPlaylistContext *ctx;
     char **flist;
     int i, len;
     ff_playlist_split_encodedstring(s, sep, &flist, &len);
@@ -181,7 +181,7 @@ PlaylistContext *ff_playlist_from_encode
     return ctx;
 }
 
-void ff_playlist_add_path(PlaylistContext *ctx, const char *itempath)
+void ff_playlist_add_path(AVPlaylistContext *ctx, const char *itempath)
 {
     ctx->flist = av_realloc(ctx->flist, sizeof(*(ctx->flist)) * (++ctx->pelist_size+1));
     ctx->flist[ctx->pelist_size] = NULL;
@@ -223,7 +223,7 @@ int64_t ff_playlist_time_offset(const in
     return total;
 }
 
-int ff_playlist_stream_index_from_time(PlaylistContext *ctx,
+int ff_playlist_stream_index_from_time(AVPlaylistContext *ctx,
                                        int64_t pts,
                                        int64_t *localpts)
 {
@@ -240,7 +240,7 @@ int ff_playlist_stream_index_from_time(P
     return i;
 }
 
-int ff_playlist_playidx_from_streamidx(PlaylistContext *ctx, int stream_index)
+int ff_playlist_playidx_from_streamidx(AVPlaylistContext *ctx, int stream_index)
 {
     int i, total;
     i = total = 0;
@@ -249,7 +249,7 @@ int ff_playlist_playidx_from_streamidx(P
     return i-1;
 }
 
-int ff_playlist_localstidx_from_streamidx(PlaylistContext *ctx, int stream_index)
+int ff_playlist_localstidx_from_streamidx(AVPlaylistContext *ctx, int stream_index)
 {
     int i, total;
     i = total = 0;
@@ -258,7 +258,7 @@ int ff_playlist_localstidx_from_streamid
     return stream_index - (total - ctx->nb_streams_list[i-1]);
 }
 
-int ff_playlist_streams_offset_from_playidx(PlaylistContext *ctx, int playidx)
+int ff_playlist_streams_offset_from_playidx(AVPlaylistContext *ctx, int playidx)
 {
     int i, total;
     i = total = 0;
@@ -25,7 +25,7 @@
  *
  *  @details These functions are used to initialize and manipulate playlists
- *  (PlaylistContext) and their individual playlist elements (PlayElem), each
+ *  (AVPlaylistContext) and their individual playlist elements (PlayElem), each
  *  of which encapsulates its own AVFormatContext. This abstraction is used for
  *  implementing file concatenation and support for playlist formats.

Modified: concat/libavformat/playlist.h
==============================================================================
--- concat/libavformat/playlist.h	Thu Aug 20 16:28:14 2009	(r5198)
+++ concat/libavformat/playlist.h	Thu Aug 20 16:35:45 2009	(r5199)
@@ -25,7 +25,7 @@
  *  @brief General components used by playlist formats
  *
  *  @details These functions are used to initialize and manipulate playlists
  *  (PlaylistContext) and their individual playlist elements (PlayElem), each
  *  of which encapsulates its own AVFormatContext. This abstraction is used for
  *  implementing file concatenation and support for playlist formats.
  */
@@ -36,17 +36,17 @@
 #include <libgen.h>
 #include "avformat.h"
 
-/** @struct PlaylistContext
+/** @struct AVPlaylistContext
  *  @brief Represents the playlist and contains PlayElem for each playlist item.
  */
-typedef struct PlaylistContext {
+typedef struct AVPlaylistContext {
     char **flist;          /**< List of file names for each playlist item */
     AVFormatContext **icl; /**< List of FormatContext for each playlist items */
     int pelist_size;       /**< Number of playlist elements stored in icl */
     int pe_curidx;         /**< Index of the AVFormatContext in icl that packets are being read from */
     int64_t *durations;    /**< Durations, in AV_TIME_BASE units, for each playlist item */
     int *nb_streams_list;  /**< List of the number of streams in each playlist item*/
-} PlaylistContext;
+} AVPlaylistContext;
 
 /** @fn AVFormatContext *ff_playlist_alloc_formatcontext(char *filename)
  *  @brief Allocates and opens file, codecs, and streams associated with filename.
@@ -55,16 +55,16 @@ typedef struct PlaylistContext {
  */
 AVFormatContext *ff_playlist_alloc_formatcontext(char *filename);
 
 /** @fn void ff_playlist_populate_context(PlaylistContext *ctx, int pe_curidx)
  *  @brief Opens the playlist element with the specified index from the PlaylistContext.
  *  @param ctx PlaylistContext containing the desired playlist element.
  *  @param pe_curidx Index of the playlist element to be opened.
  */
-void ff_playlist_populate_context(PlaylistContext *ctx, int pe_curidx);
+void ff_playlist_populate_context(AVPlaylistContext *ctx, int pe_curidx);
 
 /** @fn void ff_playlist_set_streams(AVFormatContext *s)
  *  @brief Sets the master concat-type demuxer's streams to those of its currently opened playlist element.
  *  @param s AVFormatContext of the concat-type demuxer, which contains the PlaylistContext and substreams.
  */
 void ff_playlist_set_streams(AVFormatContext *s);
 
@@ -76,12 +76,12 @@ void ff_playlist_set_streams(AVFormatCon
  */
 AVFormatContext *ff_playlist_formatcontext_from_filelist(const char **flist, int len);
 
 /** @fn PlaylistContext* ff_playlist_get_context(AVFormatContext *ic)
  *  @brief Returns PlaylistContext continaed within a concat-type demuxer.
  *  @param ic AVFormatContext of the concat-type demuxer, which contains the PlaylistContext.
  *  @return Returns NULL if failed (not concat-type demuxer or Playlist not yet allocated), or PlaylistContext if succeeded.
  */
-PlaylistContext* ff_playlist_get_context(AVFormatContext *ic);
+AVPlaylistContext* ff_playlist_get_context(AVFormatContext *ic);
 
 /** @fn void ff_playlist_relative_paths(char **flist, int len, const char *workingdir)
  *  @brief Converts a list of mixed relative or absolute paths into all absolute paths.
@@ -105,70 +105,70 @@ void ff_playlist_split_encodedstring(con
                                      char ***flist_ptr,
                                      int *len_ptr);
 
 /** @fn PlaylistContext *ff_playlist_from_filelist(const char **flist, int len)
  *  @brief Allocates and returns a PlaylistContext with playlist elements specified by a file list.
  *  @param flist List of filenames from which to construct the playlist.
  *  @param len Length of filename list.
  *  @return Returns the allocated PlaylistContext.
  */
-PlaylistContext *ff_playlist_from_filelist(const char **flist, int len);
+AVPlaylistContext *ff_playlist_from_filelist(const char **flist, int len);
 
 /** @fn PlaylistContext *ff_playlist_from_encodedstring(char *s, char sep)
  *  @brief Allocates and returns a PlaylistContext with playlist elements specified by a character-delimited string.
  *  @param s The input character-delimited string ("one,two,three").
  *  @param sep The delimiter character (',').
  *  @return Returns the allocated PlaylistContext.
  */
-PlaylistContext *ff_playlist_from_encodedstring(const char *s, const char sep);
+AVPlaylistContext *ff_playlist_from_encodedstring(const char *s, const char sep);
 
 /** @fn void ff_playlist_add_path(PlaylistContext *ctx, char *itempath)
  *  @brief Adds PlayElem for item located at specified path to a PlaylistContext.
  *  @param ctx Pre-allocated PlaylistContext to add elements to.
  *  @param itempath Absolute path to item for which to add a playlist element.
  */
-void ff_playlist_add_path(PlaylistContext *ctx, const char *itempath);
+void ff_playlist_add_path(AVPlaylistContext *ctx, const char *itempath);
 
 /** @fn int64_t ff_playlist_time_offset(int64_t *durations, int pe_curidx)
  *  @brief Calculates the total time offset of an element in a PlaylistContext in AV_TIME_BASE units.
  *  @param durations Durations of playlist items in AV_TIME_BASE units, array must be of size greater than or equal to pe_curidx.
  *  @param pe_curidx Index of the playlist element for which to calculate the time offset.
  *  @return Returns the time offset in AV_TIME_BASE units.
  */
 int64_t ff_playlist_time_offset(const int64_t *durations, int pe_curidx);
 
-/** @fn int ff_playlist_stream_index_from_time(PlaylistContext *ctx, int64_t pts, int64_t *localpts)
+/** @fn int ff_playlist_stream_index_from_time(AVPlaylistContext *ctx, int64_t pts, int64_t *localpts)
  *  @brief Calculates the index of the playlist item which would contain the timestamp specified in AV_TIME_BASE units.
  *  @param ctx PlaylistContext within which the list of playlist elements and durations are stored.
  *  @param pts Timestamp in AV_TIME_BASE.
  *  @param localpts Time in the local demuxer's timeframe in AV_TIME_BASE units; if null, not calculated.
  *  @return Returns the index of the stream which covers the specified time range.
  */
-int ff_playlist_stream_index_from_time(PlaylistContext *ctx,
+int ff_playlist_stream_index_from_time(AVPlaylistContext *ctx,
                                        int64_t pts,
                                        int64_t *localpts);
 
-/** @fn int ff_playlist_playidx_from_streamidx(PlaylistContext *ctx, int stream_index)
+/** @fn int ff_playlist_playidx_from_streamidx(AVPlaylistContext *ctx, int stream_index)
  *  @brief Calculates the index of the playlist item which contains the specified stream index.
  *  @param ctx PlaylistContext within which the list of playlist elements and durations are stored.
  *  @param stream_index Global stream index, the index of the stream within the playlist demuxer.
  *  @return Returns the index of the playlist item which contains the specified stream index.
  */
-int ff_playlist_playidx_from_streamidx(PlaylistContext *ctx, int stream_index);
+int ff_playlist_playidx_from_streamidx(AVPlaylistContext *ctx, int stream_index);
 
-/** @fn int ff_playlist_localstidx_from_streamidx(PlaylistContext *ctx, int stream_index)
+/** @fn int ff_playlist_localstidx_from_streamidx(AVPlaylistContext *ctx, int stream_index)
  *  @brief Calculates the local stream index which corresponds to a global stream index.
  *  @param ctx PlaylistContext within which the list of playlist elements and durations are stored.
  *  @param stream_index Global stream index, the index of the stream within the playlist demuxer.
  *  @return Returns the local stream index, the index of the stream within the child demuxer.
  */
-int ff_playlist_localstidx_from_streamidx(PlaylistContext *ctx, int stream_index);
+int ff_playlist_localstidx_from_streamidx(AVPlaylistContext *ctx, int stream_index);
 
-/** @fn int ff_playlist_streams_offset_from_playidx(PlaylistContext *ctx, int playidx)
+/** @fn int ff_playlist_streams_offset_from_playidx(AVPlaylistContext *ctx, int playidx)
  *  @brief Calculates the stream offset which corresponds to the given playlist item index.
  *  @param ctx PlaylistContext within which the list of playlist elements and durations are stored.
  *  @param playidx Playlist item index, the index of the child demuxer within ctx->icl.
  *  @return Returns the stream offset, which is global stream index - local stream index.
  */
-int ff_playlist_streams_offset_from_playidx(PlaylistContext *ctx, int playidx);
+int ff_playlist_streams_offset_from_playidx(AVPlaylistContext *ctx, int playidx);
 
 #endif /* AVFORMAT_PLAYLIST_H */
@@ -25,7 +25,7 @@
  *
  *  @details These functions are used to initialize and manipulate playlists
- *  (PlaylistContext) and their individual playlist elements (PlayElem), each
+ *  (AVPlaylistContext) and their individual playlist elements (PlayElem), each
  *  of which encapsulates its own AVFormatContext. This abstraction is used for
  *  implementing file concatenation and support for playlist formats.
@@ -55,16 +55,16 @@ typedef struct PlaylistContext {
 AVFormatContext *ff_playlist_alloc_formatcontext(char *filename);
 
-/** @fn void ff_playlist_populate_context(PlaylistContext *ctx, int pe_curidx)
- *  @brief Opens the playlist element with the specified index from the PlaylistContext.
- *  @param ctx PlaylistContext containing the desired playlist element.
+/** @fn void ff_playlist_populate_context(AVPlaylistContext *ctx, int pe_curidx)
+ *  @brief Opens the playlist element with the specified index from the AVPlaylistContext.
+ *  @param ctx AVPlaylistContext containing the desired playlist element.
  *  @param pe_curidx Index of the playlist element to be opened.
  */
@@ -55,16 +55,16 @@ typedef struct PlaylistContext {
 /** @fn void ff_playlist_set_streams(AVFormatContext *s)
  *  @brief Sets the master concat-type demuxer's streams to those of its currently opened playlist element.
- *  @param s AVFormatContext of the concat-type demuxer, which contains the PlaylistContext and substreams.
+ *  @param s AVFormatContext of the concat-type demuxer, which contains the AVPlaylistContext and substreams.
  */
 void ff_playlist_set_streams(AVFormatContext *s);
@@ -76,12 +76,12 @@ void ff_playlist_set_streams(AVFormatCon
 AVFormatContext *ff_playlist_formatcontext_from_filelist(const char **flist, int len);
 
-/** @fn PlaylistContext* ff_playlist_get_context(AVFormatContext *ic)
- *  @brief Returns PlaylistContext continaed within a concat-type demuxer.
- *  @param ic AVFormatContext of the concat-type demuxer, which contains the PlaylistContext.
- *  @return Returns NULL if failed (not concat-type demuxer or Playlist not yet allocated), or PlaylistContext if succeeded.
+/** @fn AVPlaylistContext* ff_playlist_get_context(AVFormatContext *ic)
+ *  @brief Returns AVPlaylistContext continaed within a concat-type demuxer.
+ *  @param ic AVFormatContext of the concat-type demuxer, which contains the AVPlaylistContext.
+ *  @return Returns NULL if failed (not concat-type demuxer or Playlist not yet allocated), or AVPlaylistContext if succeeded.
  */
@@ -105,70 +105,70 @@ void ff_playlist_split_encodedstring(con
                                      int *len_ptr);
 
-/** @fn PlaylistContext *ff_playlist_from_filelist(const char **flist, int len)
- *  @brief Allocates and returns a PlaylistContext with playlist elements specified by a file list.
+/** @fn AVPlaylistContext *ff_playlist_from_filelist(const char **flist, int len)
+ *  @brief Allocates and returns a AVPlaylistContext with playlist elements specified by a file list.
  *  @param flist List of filenames from which to construct the playlist.
  *  @param len Length of filename list.
@@ -105,70 +105,70 @@ void ff_playlist_split_encodedstring(con
  *  @param flist List of filenames from which to construct the playlist.
  *  @param len Length of filename list.
- *  @return Returns the allocated PlaylistContext.
+ *  @return Returns the allocated AVPlaylistContext.
  */
@@ -105,70 +105,70 @@ void ff_playlist_split_encodedstring(con
 
-/** @fn PlaylistContext *ff_playlist_from_encodedstring(char *s, char sep)
- *  @brief Allocates and returns a PlaylistContext with playlist elements specified by a character-delimited string.
+/** @fn AVPlaylistContext *ff_playlist_from_encodedstring(char *s, char sep)
+ *  @brief Allocates and returns a AVPlaylistContext with playlist elements specified by a character-delimited string.
  *  @param s The input character-delimited string ("one,two,three").
  *  @param sep The delimiter character (',').
@@ -105,70 +105,70 @@ void ff_playlist_split_encodedstring(con
  *  @param s The input character-delimited string ("one,two,three").
  *  @param sep The delimiter character (',').
- *  @return Returns the allocated PlaylistContext.
+ *  @return Returns the allocated AVPlaylistContext.
  */
@@ -105,70 +105,70 @@ void ff_playlist_split_encodedstring(con
 
-/** @fn void ff_playlist_add_path(PlaylistContext *ctx, char *itempath)
- *  @brief Adds PlayElem for item located at specified path to a PlaylistContext.
- *  @param ctx Pre-allocated PlaylistContext to add elements to.
+/** @fn void ff_playlist_add_path(AVPlaylistContext *ctx, char *itempath)
+ *  @brief Adds PlayElem for item located at specified path to a AVPlaylistContext.
+ *  @param ctx Pre-allocated AVPlaylistContext to add elements to.
  *  @param itempath Absolute path to item for which to add a playlist element.
  */
@@ -105,70 +105,70 @@ void ff_playlist_split_encodedstring(con
 
 /** @fn int64_t ff_playlist_time_offset(int64_t *durations, int pe_curidx)
- *  @brief Calculates the total time offset of an element in a PlaylistContext in AV_TIME_BASE units.
+ *  @brief Calculates the total time offset of an element in a AVPlaylistContext in AV_TIME_BASE units.
  *  @param durations Durations of playlist items in AV_TIME_BASE units, array must be of size greater than or equal to pe_curidx.
  *  @param pe_curidx Index of the playlist element for which to calculate the time offset.
@@ -105,70 +105,70 @@ void ff_playlist_split_encodedstring(con
  *  @brief Calculates the index of the playlist item which would contain the timestamp specified in AV_TIME_BASE units.
- *  @param ctx PlaylistContext within which the list of playlist elements and durations are stored.
+ *  @param ctx AVPlaylistContext within which the list of playlist elements and durations are stored.
  *  @param pts Timestamp in AV_TIME_BASE.
  *  @param localpts Time in the local demuxer's timeframe in AV_TIME_BASE units; if null, not calculated.
@@ -105,70 +105,70 @@ void ff_playlist_split_encodedstring(con
  *  @brief Calculates the index of the playlist item which contains the specified stream index.
- *  @param ctx PlaylistContext within which the list of playlist elements and durations are stored.
+ *  @param ctx AVPlaylistContext within which the list of playlist elements and durations are stored.
  *  @param stream_index Global stream index, the index of the stream within the playlist demuxer.
  *  @return Returns the index of the playlist item which contains the specified stream index.
@@ -105,70 +105,70 @@ void ff_playlist_split_encodedstring(con
  *  @brief Calculates the local stream index which corresponds to a global stream index.
- *  @param ctx PlaylistContext within which the list of playlist elements and durations are stored.
+ *  @param ctx AVPlaylistContext within which the list of playlist elements and durations are stored.
  *  @param stream_index Global stream index, the index of the stream within the playlist demuxer.
  *  @return Returns the local stream index, the index of the stream within the child demuxer.
@@ -105,70 +105,70 @@ void ff_playlist_split_encodedstring(con
  *  @brief Calculates the stream offset which corresponds to the given playlist item index.
- *  @param ctx PlaylistContext within which the list of playlist elements and durations are stored.
+ *  @param ctx AVPlaylistContext within which the list of playlist elements and durations are stored.
  *  @param playidx Playlist item index, the index of the child demuxer within ctx->icl.
  *  @return Returns the stream offset, which is global stream index - local stream index.

Modified: concat/libavformat/pls.c
==============================================================================